==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_tzm.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_tzm extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Derhem Uymarati" },
            { "aoa", "Kwanza Unguli" },
            { "aud", "\u1e0cular Us\u1e6drali" },
            { "bhd", "\u1e0cinar Uba\u1e25rayni" },
            { "bif", "Frank Uburundi" },
            { "bwp", "Pula Ubutswani" },
            { "cad", "\u1e0cular Ukanadi" },
            { "cdf", "Frank Ukunguli" },
            { "chf", "Frank Uswisri" },
            { "cny", "Ywan Renminbi Ucinwi" },
            { "cve", "Iskudu Ukabuvirdyani" },
            { "djf", "Frank U\u011fibuti" },
            { "dzd", "\u1e0cinar Udzayri" },
            { "egp", "Junih Umi\u1e63\u1e5bi" },
            { "ern", "Nakfa Uyritri" },
            { "etb", "Birr Uyityuppi" },
            { "eur", "U\u1e5bu" },
            { "gbp", "Junih Ubri\u1e6dani" },
            { "ghc", "Sidi U\u0263ani" },
            { "gmd", "Dalasi Agambi" },
            { "gns", "Frank U\u0263ini" },
            { "inr", "Rupi U\u1e25indi" },
            { "jpy", "Yann Ujappuni" },
            { "kes", "Cillin Ukini" },
            { "kmf", "Frank Uqumuri" },
            { "lrd", "\u1e0cular Ulibiri" },
            { "lsl", "Luti Ulusu\u1e6di" },
            { "lyd", "\u1e0cinar Ulibi" },
            { "mad", "Derhem Ume\u1e5b\u1e5buki" },
            { "mga", "Aryari Umal\u0263aci" },
            { "mro", "Uqiyya Umuritani (1973\u20132017)" },
            { "mru", "Uqiyya Umuritani" },
            { "mur", "Rupi Umurisi" },
            { "mwk", "Kwa\u010da Umalawi" },
            { "mzm", "Mitikal Umuzambiqi" },
            { "nad", "\u1e0cular Unamibi" },
            { "ngn", "Nayra Unijiri" },
            { "rwf", "Frank Urwandi" },
            { "sar", "Ryal Usa\u03b5udi" },
            { "scr", "Rupi Usicili" },
            { "sdg", "Junih Usudani" },
            { "sdp", "Junih Usudani (1956\u20132007)" },
            { "shp", "Junih Usantehilini" },
            { "sll", "Lyun Usirralyuni" },
            { "sos", "Cilin U\u1e63umali" },
            { "std", "Dubra Usaw\u1e6dumi (1977\u20132017)" },
            { "stn", "Dubra Usaw\u1e6dumi" },
            { "szl", "Lilanjini Uswazi" },
            { "tnd", "\u1e0cinar Utunsi" },
            { "tzs", "Cilin U\u1e6danzani" },
            { "ugx", "Cilin U\u0263andi (1966\u20131987)" },
            { "usd", "\u1e0cular Umirikani" },
            { "xaf", "Frank CFA (BEAC)" },
            { "xof", "Frank CFA (BCEAO)" },
            { "zar", "Rand Ufriki Unzul" },
            { "zmk", "Kwa\u010da Uzambi (1968\u20132012)" },
            { "zmw", "Kwa\u010da Uzambi" },
            { "zwd", "\u1e0cular Uzimbabwi" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_tzm.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_tzm extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Derhem Uymarati" },
            { "aoa", "Kwanza Unguli" },
            { "aud", "\u1e0cular Us\u1e6drali" },
            { "bhd", "\u1e0cinar Uba\u1e25rayni" },
            { "bif", "Frank Uburundi" },
            { "bwp", "Pula Ubutswani" },
            { "cad", "\u1e0cular Ukanadi" },
            { "cdf", "Frank Ukunguli" },
            { "chf", "Frank Uswisri" },
            { "cny", "Ywan Renminbi Ucinwi" },
            { "cve", "Iskudu Ukabuvirdyani" },
            { "djf", "Frank U\u011fibuti" },
            { "dzd", "\u1e0cinar Udzayri" },
            { "egp", "Junih Umi\u1e63\u1e5bi" },
            { "ern", "Nakfa Uyritri" },
            { "etb", "Birr Uyityuppi" },
            { "eur", "U\u1e5bu" },
            { "gbp", "Junih Ubri\u1e6dani" },
            { "ghc", "Sidi U\u0263ani" },
            { "gmd", "Dalasi Agambi" },
            { "gns", "Frank U\u0263ini" },
            { "inr", "Rupi U\u1e25indi" },
            { "jpy", "Yann Ujappuni" },
            { "kes", "Cillin Ukini" },
            { "kmf", "Frank Uqumuri" },
            { "lrd", "\u1e0cular Ulibiri" },
            { "lsl", "Luti Ulusu\u1e6di" },
            { "lyd", "\u1e0cinar Ulibi" },
            { "mad", "Derhem Ume\u1e5b\u1e5buki" },
            { "mga", "Aryari Umal\u0263aci" },
            { "mro", "Uqiyya Umuritani (1973\u20132017)" },
            { "mru", "Uqiyya Umuritani" },
            { "mur", "Rupi Umurisi" },
            { "mwk", "Kwa\u010da Umalawi" },
            { "mzm", "Mitikal Umuzambiqi" },
            { "nad", "\u1e0cular Unamibi" },
            { "ngn", "Nayra Unijiri" },
            { "rwf", "Frank Urwandi" },
            { "sar", "Ryal Usa\u03b5udi" },
            { "scr", "Rupi Usicili" },
            { "sdg", "Junih Usudani" },
            { "sdp", "Junih Usudani (1956\u20132007)" },
            { "shp", "Junih Usantehilini" },
            { "sle", "Lyun Usirralyuni" },
            { "sll", "Lyun Usirralyuni (1964\u20142022)" },
            { "sos", "Cilin U\u1e63umali" },
            { "std", "Dubra Usaw\u1e6dumi (1977\u20132017)" },
            { "stn", "Dubra Usaw\u1e6dumi" },
            { "szl", "Lilanjini Uswazi" },
            { "tnd", "\u1e0cinar Utunsi" },
            { "tzs", "Cilin U\u1e6danzani" },
            { "ugx", "Cilin U\u0263andi (1966\u20131987)" },
            { "usd", "\u1e0cular Umirikani" },
            { "xaf", "Frank CFA (BEAC)" },
            { "xof", "Frank CFA (BCEAO)" },
            { "zar", "Rand Ufriki Unzul" },
            { "zmk", "Kwa\u010da Uzambi (1968\u20132012)" },
            { "zmw", "Kwa\u010da Uzambi" },
            { "zwd", "\u1e0cular Uzimbabwi" },
        };
        return data;
    }
}
